from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class CheckAccessRequest(_message.Message):
    __slots__ = ["access_token", "inquiry"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    INQUIRY_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    inquiry: _struct_pb2.Struct
    def __init__(
        self, access_token: _Optional[str] = ..., inquiry: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...
    ) -> None: ...

class CheckAccessResponse(_message.Message):
    __slots__ = ["has_access"]
    HAS_ACCESS_FIELD_NUMBER: _ClassVar[int]
    has_access: bool
    def __init__(self, has_access: bool = ...) -> None: ...

class CreatePolicyRequest(_message.Message):
    __slots__ = ["access_token", "policy"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    policy: _struct_pb2.Struct
    def __init__(
        self, access_token: _Optional[str] = ..., policy: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...
    ) -> None: ...

class CreatePolicyResponse(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeletePolicyRequest(_message.Message):
    __slots__ = ["access_token", "id"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    id: str
    def __init__(self, access_token: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class DeletePolicyResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetPolicyListRequest(_message.Message):
    __slots__ = ["access_token", "limit", "offset"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    limit: int
    offset: int
    def __init__(
        self, access_token: _Optional[str] = ..., limit: _Optional[int] = ..., offset: _Optional[int] = ...
    ) -> None: ...

class GetPolicyListResponse(_message.Message):
    __slots__ = ["policy"]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    policy: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    def __init__(self, policy: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...) -> None: ...

class GetPolicyRequest(_message.Message):
    __slots__ = ["access_token", "id"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    id: str
    def __init__(self, access_token: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class GetPolicyResponse(_message.Message):
    __slots__ = ["policy"]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    policy: _struct_pb2.Struct
    def __init__(self, policy: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class GetUserListRequest(_message.Message):
    __slots__ = ["access_token", "limit", "offset"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    limit: int
    offset: int
    def __init__(
        self, access_token: _Optional[str] = ..., limit: _Optional[int] = ..., offset: _Optional[int] = ...
    ) -> None: ...

class GetUserListResponse(_message.Message):
    __slots__ = ["results"]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[UserInList]
    def __init__(self, results: _Optional[_Iterable[_Union[UserInList, _Mapping]]] = ...) -> None: ...

class GetUserRequest(_message.Message):
    __slots__ = ["access_token", "id"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    id: str
    def __init__(self, access_token: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class GetUserResponse(_message.Message):
    __slots__ = ["email", "id", "is_active", "is_superuser"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IS_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    IS_SUPERUSER_FIELD_NUMBER: _ClassVar[int]
    email: str
    id: str
    is_active: bool
    is_superuser: bool
    def __init__(
        self, id: _Optional[str] = ..., email: _Optional[str] = ..., is_active: bool = ..., is_superuser: bool = ...
    ) -> None: ...

class UpdatePolicyRequest(_message.Message):
    __slots__ = ["access_token", "id", "policy"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    id: str
    policy: _struct_pb2.Struct
    def __init__(
        self,
        access_token: _Optional[str] = ...,
        id: _Optional[str] = ...,
        policy: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
    ) -> None: ...

class UpdatePolicyResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UserInList(_message.Message):
    __slots__ = ["email", "id", "is_active", "is_superuser"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IS_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    IS_SUPERUSER_FIELD_NUMBER: _ClassVar[int]
    email: str
    id: str
    is_active: bool
    is_superuser: bool
    def __init__(
        self, id: _Optional[str] = ..., email: _Optional[str] = ..., is_active: bool = ..., is_superuser: bool = ...
    ) -> None: ...



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: role_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12role_service.proto\x1a\x1cgoogle/protobuf/struct.proto"2\n\x0eGetUserRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t"U\n\x0fGetUserResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x11\n\tis_active\x18\x03 \x01(\x08\x12\x14\n\x0cis_superuser\x18\x04 \x01(\x08"I\n\x12GetUserListRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05"P\n\nUserInList\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x11\n\tis_active\x18\x03 \x01(\x08\x12\x14\n\x0cis_superuser\x18\x04 \x01(\x08"3\n\x13GetUserListResponse\x12\x1c\n\x07results\x18\x01 \x03(\x0b\x32\x0b.UserInList"T\n\x13\x43reatePolicyRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\'\n\x06policy\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct""\n\x14\x43reatePolicyResponse\x12\n\n\x02id\x18\x01 \x01(\t"`\n\x13UpdatePolicyRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\'\n\x06policy\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct"\x16\n\x14UpdatePolicyResponse"7\n\x13\x44\x65letePolicyRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t"\x16\n\x14\x44\x65letePolicyResponse"4\n\x10GetPolicyRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t"<\n\x11GetPolicyResponse\x12\'\n\x06policy\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct"K\n\x14GetPolicyListRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05"@\n\x15GetPolicyListResponse\x12\'\n\x06policy\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct"T\n\x12\x43heckAccessRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12(\n\x07inquiry\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct")\n\x13\x43heckAccessResponse\x12\x12\n\nhas_access\x18\x01 \x01(\x08\x32\xd8\x03\n\tAdminRole\x12,\n\x07GetUser\x12\x0f.GetUserRequest\x1a\x10.GetUserResponse\x12\x38\n\x0bGetUserList\x12\x13.GetUserListRequest\x1a\x14.GetUserListResponse\x12;\n\x0c\x43reatePolicy\x12\x14.CreatePolicyRequest\x1a\x15.CreatePolicyResponse\x12;\n\x0cUpdatePolicy\x12\x14.UpdatePolicyRequest\x1a\x15.UpdatePolicyResponse\x12;\n\x0c\x44\x65letePolicy\x12\x14.DeletePolicyRequest\x1a\x15.DeletePolicyResponse\x12\x32\n\tGetPolicy\x12\x11.GetPolicyRequest\x1a\x12.GetPolicyResponse\x12>\n\rGetPolicyList\x12\x15.GetPolicyListRequest\x1a\x16.GetPolicyListResponse\x12\x38\n\x0b\x43heckAccess\x12\x13.CheckAccessRequest\x1a\x14.CheckAccessResponseb\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "role_service_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS is False:

    DESCRIPTOR._options = None
    _GETUSERREQUEST._serialized_start = 52
    _GETUSERREQUEST._serialized_end = 102
    _GETUSERRESPONSE._serialized_start = 104
    _GETUSERRESPONSE._serialized_end = 189
    _GETUSERLISTREQUEST._serialized_start = 191
    _GETUSERLISTREQUEST._serialized_end = 264
    _USERINLIST._serialized_start = 266
    _USERINLIST._serialized_end = 346
    _GETUSERLISTRESPONSE._serialized_start = 348
    _GETUSERLISTRESPONSE._serialized_end = 399
    _CREATEPOLICYREQUEST._serialized_start = 401
    _CREATEPOLICYREQUEST._serialized_end = 485
    _CREATEPOLICYRESPONSE._serialized_start = 487
    _CREATEPOLICYRESPONSE._serialized_end = 521
    _UPDATEPOLICYREQUEST._serialized_start = 523
    _UPDATEPOLICYREQUEST._serialized_end = 619
    _UPDATEPOLICYRESPONSE._serialized_start = 621
    _UPDATEPOLICYRESPONSE._serialized_end = 643
    _DELETEPOLICYREQUEST._serialized_start = 645
    _DELETEPOLICYREQUEST._serialized_end = 700
    _DELETEPOLICYRESPONSE._serialized_start = 702
    _DELETEPOLICYRESPONSE._serialized_end = 724
    _GETPOLICYREQUEST._serialized_start = 726
    _GETPOLICYREQUEST._serialized_end = 778
    _GETPOLICYRESPONSE._serialized_start = 780
    _GETPOLICYRESPONSE._serialized_end = 840
    _GETPOLICYLISTREQUEST._serialized_start = 842
    _GETPOLICYLISTREQUEST._serialized_end = 917
    _GETPOLICYLISTRESPONSE._serialized_start = 919
    _GETPOLICYLISTRESPONSE._serialized_end = 983
    _CHECKACCESSREQUEST._serialized_start = 985
    _CHECKACCESSREQUEST._serialized_end = 1069
    _CHECKACCESSRESPONSE._serialized_start = 1071
    _CHECKACCESSRESPONSE._serialized_end = 1112
    _ADMINROLE._serialized_start = 1115
    _ADMINROLE._serialized_end = 1587
# @@protoc_insertion_point(module_scope)
